OkHiEvent class

Constructors

OkHiEvent({required String resultType, required String methodCall, OkHiUser? user, OkHiLocation? location, String? code, String? message})
OkHiEvent.fromMap(Map<String, dynamic> map)
factory

Properties

code → String?
final
hashCode → int
The hash code for this object.
no setterinherited
location → OkHiLocation?
final
message → String?
final
methodCall → String
final
resultType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → OkHiUser?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited